@@ -14,10 +14,6 @@ import warnings
 import weakref
 from typing import TYPE_CHECKING, Any, Callable, List, Tuple
 
-from markdown_it import MarkdownIt
-from mdit_py_plugins.dollarmath.index import dollarmath_plugin
-from mdit_py_plugins.footnote.index import footnote_plugin
-
 from gradio import Examples, interpretation, utils
 from gradio.blocks import Blocks
 from gradio.components import (
@@ -139,7 +135,7 @@ class Interface(Blocks):
         theme: str = "default",
         css: str | None = None,
         allow_flagging: str | None = None,
-        flagging_options: List[str] | None = None,
+        flagging_options: List[str] | List[Tuple[str, str]] | None = None,
         flagging_dir: str = "flagged",
         flagging_callback: FlaggingCallback = CSVLogger(),
         analytics_enabled: bool | None = None,
@@ -166,7 +162,7 @@ class Interface(Blocks):
             theme: Theme to use - right now, only "default" is supported. Can be set with the GRADIO_THEME environment variable.
             css: custom css or path to custom css file to use with interface.
             allow_flagging: one of "never", "auto", or "manual". If "never" or "auto", users will not see a button to flag an input and output. If "manual", users will see a button to flag. If "auto", every input the user submits will be automatically flagged (outputs are not flagged). If "manual", both the input and outputs are flagged when the user clicks flag button. This parameter can be set with environmental variable GRADIO_ALLOW_FLAGGING; otherwise defaults to "manual".
-            flagging_options: if provided, allows user to select from the list of options when flagging. Only applies if allow_flagging is "manual".
+            flagging_options: if provided, allows user to select from the list of options when flagging. Only applies if allow_flagging is "manual". Can either be a list of tuples of the form (label, value), where label is the string that will be displayed on the button and value is the string that will be stored in the flagging CSV; or it can be a list of strings ["X", "Y"], in which case the values will be the list of strings and the labels will ["Flag as X", "Flag as Y"], etc.
             flagging_dir: what to name the directory where flagged data is stored.
             flagging_callback: An instance of a subclass of FlaggingCallback which will be called when a sample is flagged. By default logs to a local CSV file.
             analytics_enabled: Whether to allow basic telemetry. If None, will use GRADIO_ANALYTICS_ENABLED environment variable if defined, or default to True.
@@ -298,20 +294,7 @@ class Interface(Blocks):
             cleantext = re.sub(CLEANER, "", raw_html)
             return cleantext
 
-        md = (
-            MarkdownIt(
-                "js-default",
-                {
-                    "linkify": True,
-                    "typographer": True,
-                    "html": True,
-                },
-            )
-            .use(dollarmath_plugin)
-            .use(footnote_plugin)
-            .enable("table")
-        )
-
+        md = utils.get_markdown_parser()
         simple_description = None
         if description is not None:
             description = md.render(description)
@@ -369,7 +352,21 @@ class Interface(Blocks):
                 "Must be: 'auto', 'manual', or 'never'."
             )
 
-        self.flagging_options = flagging_options
+        if flagging_options is None:
+            self.flagging_options = [("Flag", "")]
+        elif not (isinstance(flagging_options, list)):
+            raise ValueError(
+                "flagging_options must be a list of strings or list of (string, string) tuples."
+            )
+        elif all([isinstance(x, str) for x in flagging_options]):
+            self.flagging_options = [(f"Flag as {x}", x) for x in flagging_options]
+        elif all([isinstance(x, tuple) for x in flagging_options]):
+            self.flagging_options = flagging_options
+        else:
+            raise ValueError(
+                "flagging_options must be a list of strings or list of (string, string) tuples."
+            )
+
         self.flagging_callback = flagging_callback
         self.flagging_dir = flagging_dir
         self.batch = batch
@@ -480,7 +477,7 @@ class Interface(Blocks):
                 interpret_component_column,
             )
 
-            self.render_flagging_buttons(flag_btns)
+            self.attach_flagging_events(flag_btns, clear_btn)
             self.render_examples()
             self.render_article()
 
@@ -496,17 +493,8 @@ class Interface(Blocks):
         if self.description:
             Markdown(self.description)
 
-    def render_flag_btns(self) -> List[Tuple[Button, str | None]]:
-        if self.flagging_options is None:
-            return [(Button("Flag"), None)]
-        else:
-            return [
-                (
-                    Button("Flag as " + flag_option),
-                    flag_option,
-                )
-                for flag_option in self.flagging_options
-            ]
+    def render_flag_btns(self) -> List[Button]:
+        return [Button(label) for label, _ in self.flagging_options]
 
     def render_input_column(
         self,
@@ -514,7 +502,7 @@ class Interface(Blocks):
         Button | None,
         Button | None,
         Button | None,
-        List | None,
+        List[Button] | None,
         Column,
         Column | None,
         List[Interpretation] | None,
@@ -556,7 +544,7 @@ class Interface(Blocks):
                     if self.allow_flagging == "manual":
                         flag_btns = self.render_flag_btns()
                     elif self.allow_flagging == "auto":
-                        flag_btns = [(submit_btn, None)]
+                        flag_btns = [submit_btn]
         return (
             submit_btn,
             clear_btn,
@@ -593,7 +581,7 @@ class Interface(Blocks):
                     flag_btns = self.render_flag_btns()
                 elif self.allow_flagging == "auto":
                     assert submit_btn is not None, "Submit button not rendered"
-                    flag_btns = [(submit_btn, None)]
+                    flag_btns = [submit_btn]
                 if self.interpretation:
                     interpretation_btn = Button("Interpret")
 
@@ -750,29 +738,53 @@ class Interface(Blocks):
                 preprocess=False,
             )
 
-    def render_flagging_buttons(self, flag_btns: List | None):
+    def attach_flagging_events(self, flag_btns: List[Button] | None, clear_btn: Button):
         if flag_btns:
             if self.interface_type in [
                 InterfaceTypes.STANDARD,
                 InterfaceTypes.OUTPUT_ONLY,
                 InterfaceTypes.UNIFIED,
             ]:
-                if (
-                    self.interface_type == InterfaceTypes.UNIFIED
-                    or self.allow_flagging == "auto"
-                ):
+                if self.allow_flagging == "auto":
+                    flag_method = FlagMethod(
+                        self.flagging_callback, "", "", visual_feedback=False
+                    )
+                    flag_btns[0].click(  # flag_btns[0] is just the "Submit" button
+                        flag_method,
+                        inputs=self.input_components,
+                        outputs=None,
+                        preprocess=False,
+                        queue=False,
+                    )
+                    return
+
+                if self.interface_type == InterfaceTypes.UNIFIED:
                     flag_components = self.input_components
                 else:
                     flag_components = self.input_components + self.output_components
-                for flag_btn, flag_option in flag_btns:
-                    flag_method = FlagMethod(self.flagging_callback, flag_option)
+
+                for flag_btn, (label, value) in zip(flag_btns, self.flagging_options):
+                    assert isinstance(value, str)
+                    flag_method = FlagMethod(self.flagging_callback, label, value)
+                    flag_btn.click(
+                        lambda: Button.update(value="Saving...", interactive=False),
+                        None,
+                        flag_btn,
+                        queue=False,
+                    )
                     flag_btn.click(
                         flag_method,
                         inputs=flag_components,
-                        outputs=[],
+                        outputs=flag_btn,
                         preprocess=False,
                         queue=False,
                     )
+                    clear_btn.click(
+                        flag_method.reset,
+                        None,
+                        flag_btn,
+                        queue=False,
+                    )
 
     def render_examples(self):
         if self.examples:
