@@ -41,6 +41,9 @@ import fsspec.asyn
 import httpx
 import matplotlib.pyplot as plt
 import requests
+from markdown_it import MarkdownIt
+from mdit_py_plugins.dollarmath.index import dollarmath_plugin
+from mdit_py_plugins.footnote.index import footnote_plugin
 from pydantic import BaseModel, Json, parse_obj_as
 
 import gradio
@@ -336,23 +339,15 @@ def format_ner_list(input_string: str, ner_groups: List[Dict[str, str | int]]):
     return output
 
 
-def delete_none(_dict: T, skip_value: bool = False) -> T:
+def delete_none(_dict: Dict, skip_value: bool = False) -> Dict:
     """
-    Delete None values recursively from all of the dictionaries, tuples, lists, sets.
-    Credit: https://stackoverflow.com/a/66127889/5209347
+    Delete keys whose values are None from a dictionary
     """
-    if isinstance(_dict, dict):
-        for key, value in list(_dict.items()):
-            if skip_value and key == "value":
-                continue
-            if isinstance(value, (list, dict, tuple, set)):
-                _dict[key] = delete_none(value)
-            elif value is None or key is None:
-                del _dict[key]
-
-    elif isinstance(_dict, (list, set, tuple)):
-        _dict = type(_dict)(delete_none(item) for item in _dict if item is not None)
-
+    for key, value in list(_dict.items()):
+        if skip_value and key == "value":
+            continue
+        elif value is None:
+            del _dict[key]
     return _dict
 
 
@@ -891,6 +886,12 @@ def tex2svg(formula, *args):
     svg_start = xml_code.index("<svg ")
     svg_code = xml_code[svg_start:]
     svg_code = re.sub(r"<metadata>.*<\/metadata>", "", svg_code, flags=re.DOTALL)
+    svg_code = re.sub(r' width="[^"]+"', "", svg_code)
+    height_match = re.search(r'height="([\d.]+)pt"', svg_code)
+    if height_match:
+        height = float(height_match.group(1))
+        new_height = height / FONTSIZE  # conversion from pt to em
+        svg_code = re.sub(r'height="[\d.]+pt"', f'height="{new_height}em"', svg_code)
     copy_code = f"<span style='font-size: 0px'>{formula}</span>"
     return f"{copy_code}{svg_code}"
 
@@ -901,3 +902,29 @@ def abspath(path: str | Path) -> Path:
         return Path.cwd() / path
     else:
         return Path(path).resolve()
+
+
+def get_markdown_parser() -> MarkdownIt:
+    md = (
+        MarkdownIt(
+            "js-default",
+            {
+                "linkify": True,
+                "typographer": True,
+                "html": True,
+                "breaks": True,
+            },
+        )
+        .use(dollarmath_plugin, renderer=tex2svg, allow_digits=False)
+        .use(footnote_plugin)
+        .enable("table")
+    )
+
+    # Add target="_blank" to all links. Taken from MarkdownIt docs: https://github.com/executablebooks/markdown-it-py/blob/master/docs/architecture.md
+    def render_blank_link(self, tokens, idx, options, env):
+        tokens[idx].attrSet("target", "_blank")
+        return self.renderToken(tokens, idx, options, env)
+
+    md.add_render_rule("link_open", render_blank_link)
+
+    return md
