@@ -325,6 +325,37 @@ class TestBlocksMethods:
                     completed = True
             assert msg["output"]["data"][0] == "Victor"
 
+    def test_function_types_documented_in_config(self):
+        def continuous_fn():
+            return 42
+
+        def generator_function():
+            for index in range(10):
+                yield index
+
+        with gr.Blocks() as demo:
+
+            gr.Number(value=lambda: 2, every=2)
+            meaning_of_life = gr.Number()
+            counter = gr.Number()
+            generator_btn = gr.Button(value="Generate")
+            greeting = gr.Textbox()
+            greet_btn = gr.Button(value="Greet")
+
+            greet_btn.click(lambda: "Hello!", inputs=None, outputs=[greeting])
+            generator_btn.click(generator_function, inputs=None, outputs=[counter])
+            demo.load(continuous_fn, inputs=None, outputs=[meaning_of_life], every=1)
+
+        for i, dependency in enumerate(demo.config["dependencies"]):
+            if i == 0:
+                assert dependency["types"] == {"continuous": True, "generator": True}
+            if i == 1:
+                assert dependency["types"] == {"continuous": False, "generator": False}
+            if i == 2:
+                assert dependency["types"] == {"continuous": False, "generator": True}
+            if i == 3:
+                assert dependency["types"] == {"continuous": True, "generator": True}
+
     @pytest.mark.asyncio
     async def test_run_without_launching(self):
         """Test that we can start the app and use queue without calling .launch().
@@ -414,11 +445,13 @@ class TestComponentsInBlocks:
                 components.append(component(value=lambda: None, every=1))
         assert [comp.load_event for comp in components] == demo.dependencies
 
+
+class TestBlocksPostprocessing:
     def test_blocks_do_not_filter_none_values_from_updates(self, io_components):
         io_components = [
             c()
             for c in io_components
-            if c not in [gr.State, gr.Button, gr.ScatterPlot, gr.LinePlot]
+            if c not in [gr.State, gr.Button, gr.ScatterPlot, gr.LinePlot, gr.BarPlot]
         ]
         with gr.Blocks() as demo:
             for component in io_components:
@@ -531,6 +564,18 @@ class TestComponentsInBlocks:
             }
             assert output["data"][1] == {"__type__": "update", "mode": "dynamic"}
 
+    def test_error_raised_if_num_outputs_mismatch(self):
+        with gr.Blocks() as demo:
+            textbox1 = gr.Textbox()
+            textbox2 = gr.Textbox()
+            button = gr.Button()
+            button.click(lambda x: x, textbox1, [textbox1, textbox2])
+        with pytest.raises(
+            ValueError,
+            match="Number of output components does not match number of values returned from from function <lambda>",
+        ):
+            demo.postprocess_data(fn_index=0, predictions=["test"], state={})
+
 
 class TestCallFunction:
     @pytest.mark.asyncio
